@import "../../../../css/_mixins.scss";
@import "../../../../css/_theme-vars.scss";
@import "../../css/_skin-vars.scss";


@media #{$media_xl} {
	// Titles -> Outside Top
	.slider_outer.slider_outer_titles_outside_top {
		.slide_info {
			.slide_title,
			.slide_number {
				font-size: 50px;
			}
		}
	}
}

//@mixin trx_addons--lg() {
@media #{$media_lg} {
	/* ThemeREX Addons */

	ul[class*="trx_addons_list_success"] {
		padding-left: 30px;
		> li {
			margin: 5px 0;
		}
	}

	/* Recent News on expanded pages */
	body.expand_content .sc_recent_news_style_news-announce .post_size_full {	height: 540px; }
	body.expand_content .sc_recent_news_style_news-announce .post_size_big {	height: 270px;  }
	body.expand_content .sc_recent_news_style_news-announce .post_size_medium,
	body.expand_content .sc_recent_news_style_news-announce .post_size_small {	height: 135px;  }

    /* Content Area: Tablet */
	.sc-tablet_inner_width_1_1 > .elementor-column-wrap, .sc-tablet_inner_width_1_1 > .elementor-widget-wrap {	width: var(--theme-var-page); }
	.sc-tablet_inner_width_1_2 > .elementor-column-wrap, .sc-tablet_inner_width_1_2 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 2 ); }
	.sc-tablet_inner_width_1_3 > .elementor-column-wrap, .sc-tablet_inner_width_1_3 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 3 ); }
	.sc-tablet_inner_width_2_3 > .elementor-column-wrap, .sc-tablet_inner_width_2_3 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 3 * 2 ); }
	.sc-tablet_inner_width_1_4 > .elementor-column-wrap, .sc-tablet_inner_width_1_4 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 4 ); }
	.sc-tablet_inner_width_3_4 > .elementor-column-wrap, .sc-tablet_inner_width_3_4 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 4 * 3 ); }

	.sc-tablet_inner_width_none > .elementor-column-wrap, .sc-tablet_inner_width_none > .elementor-widget-wrap {	width: 100%; }
	.menu_side_present .sc-tablet_inner_width_none > .elementor-column-wrap, .menu_side_present .sc-tablet_inner_width_none > .elementor-widget-wrap {	width: calc( 100% - var(--theme-var-menu_side) ); }

	/* Expand / Collapse */
	.trx_expcol_on .trx_expcol_button {
		padding: 16px 35px;
	}

	/* AI Helper Image Generator */
	.sc_igenerator_form_field_inner {
		> .select_container select,
		> .sc_igenerator_form_field_model_wrap > .select_container select,
		> .sc_igenerator_form_field_numeric_wrap input[type="number"],
		> input[type="text"],
		> .theme_form_field_text {
			height: 52px;
		}
	}
	.sc_igenerator_form_field_prompt {
		.sc_igenerator_form_field_prompt_button {
			height: 44px;
			line-height: 42px;
		}
	} 
	.sc_igenerator_form_settings_button {
		width: 52px;
	}
	/* Extended */
	/* AI Helper Text Generator */
	.sc_tgenerator_result .sc_tgenerator_result_copy .sc_button {
		padding: 12px 26px;
	}
	.sc_tgenerator_text, 
	.sc_tgenerator_result {
		h1, h2, h3, h4, h5, h6 {
			margin: 0 0 0.6em 0;
		}
		p, ol, ul, dl {
			margin: 0 0 1em 0;
		}
		h1 {font-size: 27px;}
		h2 {font-size: 25px;}
		h3 {font-size: 23px;}
		h4 {font-size: 21px;}
		h5 {font-size: 19px;}
		h6 {font-size: 18px;}
	}
	/* AI Helper Chat */
	.sc_chat_form_field_prompt_label {
		padding: 1.2em 1.6em;
		.sc_chat_form_start_new {
			right: 0.5em;
		}
	}
	.sc_chat_form_field_prompt {
		padding: 1.6em;
	}
	.sc_chat_form_field_tags {
		padding: 0 1.6em;
		&.sc_chat_form_field_tags_before {
			padding-top: 1.6em;
		}
		&.sc_chat_form_field_tags_after {
			padding-bottom: 1.6em;
		}
	}
	.sc_chat_result {
		padding: 1.6em 1.6em 0 1.6em;
		.sc_chat_list {
			.sc_chat_list_item {
				.sc_chat_list_item_content {
					h1, h2, h3, h4, h5, h6 {
						margin: 0 0 0.6em 0;
					}
					p, ol, ul, dl {
						margin: 0 0 1em 0;
					}
					h1 {font-size: 27px;}
					h2 {font-size: 25px;}
					h3 {font-size: 23px;}
					h4 {font-size: 21px;}
					h5 {font-size: 19px;}
					h6 {font-size: 18px;}
				}
			}
		}
	}

	// Titles -> Outside Top
	.slider_outer.slider_outer_titles_outside_top {
		padding-top: 8em;
		.slider_titles_outside_wrap {
			padding: 0 var(--theme-var-grid_gap);
		}
		.slide_info {
			.slide_title,
			.slide_number {
				font-size: 46px;
			}
		}
	}

	/* Layouts Title Breadcrumbs */
	.sc_layouts_title_breadcrumbs {
		margin-top: 1em;
	}
}

//@mixin trx_addons--md() {
@media #{$media_md} {
	/* ThemeREX Addons */

	/* Recent News on expanded pages */
	body.expand_content .sc_recent_news_style_news-announce .post_size_full {	width: 100%; height: 198px; }
	body.expand_content .sc_recent_news_style_news-announce .post_size_big {	width: 100%; height: 198px;  }
	body.expand_content .sc_recent_news_style_news-announce .post_size_medium,
	body.expand_content .sc_recent_news_style_news-announce .post_size_small {	width: 100%; height: 198px;  }

	.sc_layouts_title_link {
		margin: 2em 0 0.5em;
	}
	.sc_blogger.sc_item_filters_tabs_left .sc_item_filters_tabs li > a {
		margin-bottom: 0;
	}
	.sc_portfolio_preview .sc_portfolio_preview_description .portfolio_page_details_item_title {
		width: 40%;
	}
	.sc_portfolio_preview .sc_portfolio_preview_description .portfolio_page_details_item_value {
		width: 60%;
	}
	.sc_portfolio_preview_show .post_description {
		font-size: 1em;
	}

	/* Hotspot Default */
	.sc_hotspot_default {
		display: inline-block;
		.sc_hotspot_item_popup {
			width: 240px;
			padding: 20px;
			.sc_hotspot_item_popup_close {
				@include box(1.5em, 1.5em, 1.5em);
				.trx_addons_button_close_icon {
					font-size: 12px;
				}
			}
			.sc_hotspot_item_image + [class*="sc_hotspot_item"] {
				margin-top: 16px;
			}
		}
	}
	/* Hotspot Simple */
	.sc_hotspot_simple {
		display: inline-block;
		.sc_hotspot_item_popup {
			max-width: 200px;
		}
	}

	/* Switcher */
	.sc_switcher_controls {
		margin-bottom: 2em;
	}
	/* Switcher Tabs */
	.sc_switcher_tabs .sc_switcher_tab {
		padding: 20px;
		+ .sc_switcher_tab {
			margin-left: 20px;
		}
	}
	// custom tabs
	.style-switcher-tabs {
		.sc_switcher_tabs_controls {
			flex-wrap: wrap;
		}
		.sc_switcher_tab {
			width: calc(50% - 4px);
			flex-grow: 1;
			&,
			+ .sc_switcher_tab {
				margin: 2px;
			}
		}
	}

	/* Squeeze images */
	.sc_squeeze_titles .sc_squeeze_title {
		.sc_squeeze_title_text {
			font-size: 2.2em;
		}
	}

	// Titles -> Outside Top
	.slider_outer.slider_outer_titles_outside_top {
		padding-top: 7.6em;
		.slide_info {
			padding-right: 40px;
			.slide_title,
			.slide_number {
				font-size: 38px;
			}
		}
	}
}

//@mixin trx_addons--sm() {
@media #{$media_sm} {
	/* ThemeREX Addons */

	/* CPT */
	.post-type-archive-cpt_portfolio .sc_portfolio_default,
	.post-type-archive-cpt_services .sc_services_default,
	.post-type-archive-cpt_team .sc_team_default {
		.trx_addons_columns_wrap:not(.columns_in_single_row) {
			margin-bottom: -20px;
		}
	}

	/* Recent News on expanded pages */
	body.expand_content .sc_recent_news_style_news-announce .post_size_full {	width: 100%; height: 124px; }
	body.expand_content .sc_recent_news_style_news-announce .post_size_big {	width: 100%; height: 124px;  }
	body.expand_content .sc_recent_news_style_news-announce .post_size_medium,
	body.expand_content .sc_recent_news_style_news-announce .post_size_small {	width: 100%; height: 124px;  }

    /* Content Area: Mobile */
	.sc-mobile_inner_width_1_1 > .elementor-column-wrap, .sc-mobile_inner_width_1_1 > .elementor-widget-wrap {	width: var(--theme-var-page); }
	.sc-mobile_inner_width_1_2 > .elementor-column-wrap, .sc-mobile_inner_width_1_2 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 2 ); }
	.sc-mobile_inner_width_1_3 > .elementor-column-wrap, .sc-mobile_inner_width_1_3 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 3 ); }
	.sc-mobile_inner_width_2_3 > .elementor-column-wrap, .sc-mobile_inner_width_2_3 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 3 * 2 ); }
	.sc-mobile_inner_width_1_4 > .elementor-column-wrap, .sc-mobile_inner_width_1_4 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 4 ); }
	.sc-mobile_inner_width_3_4 > .elementor-column-wrap, .sc-mobile_inner_width_3_4 > .elementor-widget-wrap {	width: calc( var(--theme-var-page) / 4 * 3 ); }
	.sc-mobile_inner_width_none > .elementor-column-wrap, .sc-mobile_inner_width_none > .elementor-widget-wrap,
	.menu_side_present .sc-mobile_inner_width_none > .elementor-column-wrap, .menu_side_present .sc-mobile_inner_width_none > .elementor-widget-wrap {	width: 100%; }

	/* Stack rows */
	.menu_side_right .sc_stack_section_fixed {		right: 0 !important; }
	.menu_side_left .sc_stack_section_fixed {		left: 0 !important; }

	/* Video player in narrow content */
	.narrow_content .trx_addons_video_list_controller_bottom .trx_addons_video_list_controller_wrap .trx_addons_video_list_controller_item {
		.trx_addons_video_list_image {
			width: 30%;
		}
		.trx_addons_video_list_subtitle,
		.trx_addons_video_list_meta {
			display: none;
		}
	}

	/* Video sticky */
	.trx_addons_video_sticky_on {
		.trx_addons_video_sticky_inner {
			.trx_addons_video_list_title_wrap {
				background-color: var(--theme-color-bg_color_09);

				.trx_addons_video_list_title {
					color: var(--theme-color-text_dark);
				}
			}
		}
	}

	/* Services: Style 'Callouts' */
	.sc_services_callouts.sc_services_featured_top,
	.sc_services_callouts.sc_services_featured_bottom {
		.row.columns_padding_bottom.columns_in_single_row > [class*="column-"],
		.columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="column-"],
		.trx_addons_columns_wrap.columns_padding_bottom.columns_in_single_row > [class*="trx_addons_column-"] {
			padding-bottom: calc( 2 * var(--theme-var-grid_gap) );
		}
	}

	/* filter */
	.sc_item_filters_align_left .sc_item_filters_header, .sc_item_filters_align_right .sc_item_filters_header {
		flex-basis: auto;
	}
	.sc_item_filters_align_right .sc_item_filters_tabs li,
	.sc_item_filters_tabs li {
		padding: 0 0.5em;
	}
	.sc_blogger.sc_item_filters_tabs_left .sc_item_filters_tabs li > a {
		margin-bottom: 0;
	}
	.sc_item_filters_align_right .sc_item_filters_tabs,
	.sc_item_filters_align_right .sc_item_filters_more_link_wrap {
		order: 2;
		margin-bottom: 0 !important;
	}
	.sc_portfolio_preview {
		overflow-y: scroll;
	}

	.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom,
	.sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
		margin-top: 1em;
	}
	.sc_blogger .slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
		margin-top: 1em;
	}

	/* Breadcrumbs */
	.sc_layouts_title_breadcrumbs {
		margin-top: 0.7em;
	}
	.sc_layouts_title .breadcrumbs .underline_hover {
		padding-bottom: 2px;
		margin-bottom: -1px;
	}

	/* Hotspot Default */
	.sc_hotspot_default .sc_hotspot_item_popup {
		width: 200px;
		padding: 18px;
		.sc_hotspot_item_title {
			font-size: 18px;
		}
		.sc_hotspot_item_price {
			font-size: 17px;
		}
	}

	/* Switcher */
	.sc_switcher_controls_section_title {
		font-size: 17px;
	}
	.sc_switcher_controls_section1 {
		margin-right: 0.8em;
	}
	.sc_switcher_controls_section2 {
		margin-left: 0.8em;
	}
	.sc_switcher_controls_toggle {
		width: 50px;
	}
	.sc_switcher_controls_toggle_button {
		.sc_switcher_controls_toggle:not(.sc_switcher_controls_toggle_on) & {
			@include transform(translateX(20px));
		}
	}
	
	/* Switcher Tabs */
	.sc_switcher_tabs {
		.sc_switcher_tabs_controls {
			flex-wrap: wrap;
			margin-left: -2px;
			margin-right: -2px;
		}
		.sc_switcher_tab {
			width: calc(50% - 4px);
			flex-grow: 1;
			&,
			+ .sc_switcher_tab {
				margin: 2px;
			}
		}
	}

	/* Expand / Collapse */
	.trx_expcol_on .trx_expcol_button {
		padding: 14px 31px;
		font-size: 14px;
	}

	/* AI Helper Image Generator */
	.sc_igenerator_form_field_tags_item {
		padding: 8px 11px;
	}
	.sc_igenerator_form_field_tags_label {
		padding: 6px 8px 6px 0;
	}
	.sc_igenerator_form_field_inner {
		> .select_container select,
		> .sc_igenerator_form_field_model_wrap > .select_container select,
		> .sc_igenerator_form_field_numeric_wrap input[type="number"],
		> input[type="text"],
		> .theme_form_field_text {
			padding: 0 15px;
			height: 48px;
		}
		> .sc_igenerator_form_field_numeric_wrap {
			input[type="number"] {
				padding-right: 2.8em;
			}
		}
	}
	.sc_igenerator_form_field_prompt {
		.sc_igenerator_form_field_prompt_button {
			right: 4px;
			padding: 0 20px;
			height: 40px;
			@include font(14px, 38px);
		}
	}
	.sc_igenerator_form_settings_button {
		width: 48px;
	}
	/* Extended */
	.sc_igenerator_extended {
		.sc_igenerator_form_fields {
			padding: 1.5em 0;
			gap: 1.5em;
		}
	}
	/* AI Helper Text Generator */
	.sc_tgenerator_form_field_prompt {
		input[type="text"] {
			padding-left: 15px;
			padding-right: 125px;
			height: 48px;
		}
		.sc_tgenerator_form_field_prompt_button {
			right: 4px;
			padding: 0 20px;
			height: 40px;
			@include font(14px, 38px);
		}
	} 
	.sc_tgenerator_result .sc_tgenerator_result_copy .sc_button {
		padding: 10px 20px;
	}
	.sc_tgenerator_text,
	.sc_tgenerator_result {
		h1, h2, h3, h4, h5, h6 {
			margin: 0 0 0.5em 0;
		}
		p, ol, ul, dl {
			margin: 0 0 0.8em 0;
		}
		h1 {font-size: 24px;}
		h2 {font-size: 22px;}
		h3 {font-size: 20px;}
		h4 {font-size: 19px;}
		h5 {font-size: 18px;}
		h6 {font-size: 17px;}
	}
	/* AI Helper Chat */
	.sc_chat_form_field_prompt {
		input[type="text"] {
			padding-left: 15px;
			padding-right: 125px;
			height: 48px;
		}
		.sc_chat_form_field_prompt_button {
			right: 4px;
			padding: 0 20px;
			height: 40px;
			@include font(14px, 38px);
		}
	}
	.sc_chat_form_field_prompt_label {
		padding: 1em 1.2em;
		.sc_chat_form_start_new {
			padding: 0.5em;
		}
	}
	.sc_chat_form_field_tags {
		padding: 0 1.2em;
		&.sc_chat_form_field_tags_before {
			padding-top: 1.2em;
		}
		&.sc_chat_form_field_tags_after {
			padding-bottom: 1.2em;
		}
	}
	.sc_chat_form_field_prompt {
		padding: 1.2em;
	}
	.sc_chat_result {
		padding: 1.2em 1.2em 0 1.2em;
		.sc_chat_list {
			.sc_chat_list_item {
				.sc_chat_list_item_content {
					h1, h2, h3, h4, h5, h6 {
						margin: 0 0 0.5em 0;
					}
					p, ol, ul, dl {
						margin: 0 0 0.8em 0;
					}
					h1 {font-size: 24px;}
					h2 {font-size: 22px;}
					h3 {font-size: 20px;}
					h4 {font-size: 19px;}
					h5 {font-size: 18px;}
					h6 {font-size: 17px;}
				}
			}
		}
	} 
	.sc_chat_form_field_tags_item {
		padding: 8px 11px;
	}
	.sc_chat_form_field_tags_label {
		padding: 6px 8px 6px 0;
	}
	/* Squeeze images */
	.sc_squeeze_titles .sc_squeeze_title {
		.sc_squeeze_title_text {
			font-size: 1.6em;
		}
		.sc_squeeze_subtitle_text {
			line-height: 16px;
			margin-bottom: 6px;
		}
	}

	// Titles -> Outside Top
	.slider_outer.slider_outer_titles_outside_top {
		padding-top: 6em;
		.slider_titles_outside_wrap {
			top: 1.4em;
		}
		.slide_info {
			padding-right: 30px;
			.slide_cats {
				line-height: 16px;
			}
			.slide_title,
			.slide_number {
				font-size: 30px;
			}
		}
	}
}
//@mixin trx_addons--sm_wp() {
@media #{$media_sm_wp} {
	/* AI Helper Image Generator */
	/* Extended */
	.sc_igenerator_extended {
		.sc_igenerator_form_fields {
			gap: 0;
		}
		.sc_igenerator_form_field,
		.sc_igenerator_form_field:last-child:not(.sc_igenerator_form_field_generate) {
			margin: 0 0 1em 0;
		}
	} 
}

//@mixin trx_addons--xs() {
@media #{$media_xs} {
	/* ThemeREX Addons */

	/* Video player in narrow content */
	.narrow_content .trx_addons_video_list_controller_bottom .trx_addons_video_list_controller_wrap .trx_addons_video_list_controller_item {
		.trx_addons_video_list_image {
			width: 50%;
		}
	}

	/* Search */
	.search_wrap .search_results {
		padding: 2em 1em;
	}

	.sc_portfolio_preview_show .post_title {
		font-size: 20px;
		line-height: 24px;
	}

	/* Switcher */
	.sc_switcher_controls {
		margin-bottom: 1.5em;
	}
	/* Switcher Tabs */
	.sc_switcher_tabs {
		.sc_switcher_tabs_controls {
			display: block;
			margin-left: 0;
			margin-right: 0;
		}
		.sc_switcher_tab {
			width: 100%;
			margin: 0;
			+ .sc_switcher_tab {
				margin: 10px 0 0 0;
			}
		}
	}

	/* AI Helper Image Generator */
	.sc_igenerator_form_field_tags_label {
		padding: 0 0 10px 0;
	} 
	/* Extended */
	.sc_igenerator_extended {
		.sc_igenerator_form_actions_list {
			gap: 1.5em;
		}
		.sc_igenerator_form_actions_item {
			> a {
				@include font(14px, 18px);
			}
		} 
	} 
	/* Squeeze images */
	.sc_squeeze_titles .sc_squeeze_title .sc_squeeze_title_text {
		font-size: 1.4em;
	}

	// Titles -> Outside Top
	.slider_outer.slider_outer_titles_outside_top {
		.slide_info {
			.slide_title,
			.slide_number {
				font-size: 26px;
			}
		}
	}
}
